#
# This script was written by Carsten Koch-Mauthe <c.koch-mauthe at dn-systems.de>
# This script is released under the GNU GPLv2
#
# $Revision: 01 $

if(description)
{

 script_id(90018);
 script_version ("$Revision: 01 $");
 name["english"] = "Adobe Flash Player 9.0.115.0 and earlier vulnerability";
 script_name(english:name["english"]);

 desc["english"] = "The remote host is probably affected by the vulnerabilities described in
CVE-2007-5275, CVE-2007-6019, CVE-2007-6243, CVE-2007-6637, CVE-2008-1654, CVE-2008-1655

Impact
   CVE 2007-5275
     The Adobe Macromedia Flash 9 plug-in allows remote attackers to cause
     a victim machine to establish TCP sessions with arbitrary hosts via a
     Flash (SWF) movie, related to lack of pinning of a hostname to a single
     IP address after receiving an allow-access-from element in a 
     cross-domain-policy XML document, and the availability of a Flash Socket
     class that does not use the browser's DNS pins, aka DNS rebinding attacks,
     a different issue than CVE-2002-1467 and CVE-2007-4324.
   CVE 2007-6019
     Adobe Flash Player 9.0.115.0 and earlier, and 8.0.39.0 and earlier,
     allows remote attackers to execute arbitrary code via an SWF file with
     a modified DeclareFunction2 Actionscript tag, which prevents an object
     from being instantiated properly.
   CVE 2007-6243
     Adobe Flash Player 9.x up to 9.0.48.0, 8.x up to 8.0.35.0, and 7.x 
     up to 7.0.70.0 does not sufficiently restrict the interpretation and 
     usage of cross-domain policy files, which makes it easier for remote 
     attackers to conduct cross-domain and cross-site scripting (XSS) attacks. 
   CVE 2007-6637
     Multiple cross-site scripting (XSS) vulnerabilities in Adobe Flash 
     Player allow remote attackers to inject arbitrary web script or HTML
     via a crafted SWF file, related to 'pre-generated SWF files' and Adobe
     Dreamweaver CS3 or Adobe Acrobat Connect. NOTE: the asfunction: vector
     is already covered by CVE-2007-6244.1. 
   CVE 2008-1654
     Interaction error between Adobe Flash and multiple Universal Plug and Play
     (UPnP) services allow remote attackers to perform Cross-Site Request 
     Forgery (CSRF) style attacks by using the Flash navigateToURL function
     to send a SOAP message to a UPnP control point, as demonstrated by changing
     the primary DNS server. 
   CVE 2008-1655
     Unspecified vulnerability in Adobe Flash Player 9.0.115.0 and earlier,
     and 8.0.39.0 and earlier, makes it easier for remote attackers to 
     conduct DNS rebinding attacks via unknown vectors. 


References:
    http://www.cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2007-5275
    http://www.cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2007-6019
    http://www.cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2007-6243
    http://www.cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2007-6637
    http://www.cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2008-1654
    http://www.cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2008-1655

Solution:
    All Adobe Flash Player users should upgrade to the latest version:


Risk factor : High
";

 script_description(english:desc["english"]);
 summary["english"] = "Determines the Version of Flashplayer";
 script_summary(english:summary["english"]);
 script_category(ACT_GATHER_INFO);
 script_copyright(english:"This script is under GPLv2");
 family["english"] = "Local test";
 script_family(english:family["english"]);
 script_dependencies("ssh_authorization.nasl");
 exit(0);
}

#
# The code starts here
#

include("version_func.inc");

flashplcnt = 0;
sec_hole = 0;
grep = find_bin(prog_name:"grep");
grep = chomp(grep[0]);
r = find_bin(prog_name:"flashplayer");
r = make_list(r,find_file(file_name:"/libflashplayer.so"));
garg[0] = "-o";
garg[1] = "-m1";
garg[2] = "-a";
garg[3] = string("[0-9]\\+,[0-9]\\+,[0-9]\\+,[0-9]\\+");
foreach binary_name (r) {
  binary_name = chomp(binary_name);
  if (islocalhost()) {
    garg[4] = binary_name;
    arg = garg;
  } else {
    arg = garg[0]+" "+garg[1]+" "+garg[2]+" "+raw_string(0x22)+garg[3]+raw_string(0x22)+" "+binary_name;
  }
  ver = get_bin_version(full_prog_name:grep, version_argv:arg, ver_pattern:"([0-9]+,[0-9]+,[0-9]+,[0-9]+)");
  if(ver != NULL) {
    flashplcnt++;
    if(version_is_less_equal(version:ver[0], test_version:"9,0,115,0") ) {
      if(sec_hole == 0) {
        security_hole(port:0, proto:"Adobe Flash Player");
        sec_hole = 1;
      }
      security_hole(port:0, proto:"Adobe Flash Player", data:string("\nFound : ") + binary_name + "  Version : " + ver[0] + string("\n"));
    }
  }
}

if(report_verbosity > 1) {
  if(flashplcnt == 0) {
    report = "Adobe Flash Player not found or ssh login not possible on this host." + string("\n");
    security_note(port:0, proto:"Adobe Flash Player", data:report);
  }
}
exit(0);
